@@ -1,10 +1,11 @@
 import os
 import sys
-import typing as t
-from contextlib import suppress
 from uuid import UUID
 from warnings import catch_warnings, filterwarnings
 
+import typing as t
+from contextlib import suppress
+
 try:
     from cloudflare import Cloudflare as CloudflareClient
 except Exception:  # pragma: no cover - only when Cloudflare lib missing
@@ -17,6 +18,7 @@ except Exception:  # pragma: no cover - only when Cloudflare lib missing
 from pydantic import SecretStr
 from validators import domain
 from validators.utils import ValidationError
+
 from acb.adapters import AdapterCapability, AdapterMetadata, AdapterStatus
 from acb.depends import depends
 
@@ -142,7 +144,7 @@ class Dns(DnsBase):
 
     def list_records(self) -> list[DnsRecord]:
         if not self.zone_id:
-            self.logger.error("Zone ID not found. Initialize the adapter first.")
+            self.logger.error("Zone ID not found. Initialize the adapter first")
             msg = "Zone ID not found"
             raise ValueError(msg)
         try:
@@ -166,7 +168,7 @@ class Dns(DnsBase):
 
     async def _delete_record(self, record_id: str) -> None:
         if not self.zone_id:
-            self.logger.error("Zone ID not found. Initialize the adapter first.")
+            self.logger.error("Zone ID not found. Initialize the adapter first")
             msg = "Zone ID not found"
             raise ValueError(msg)
         try:
@@ -181,7 +183,7 @@ class Dns(DnsBase):
 
     async def _create_record(self, record: DnsRecord) -> None:
         if not self.zone_id:
-            self.logger.error("Zone ID not found. Initialize the adapter first.")
+            self.logger.error("Zone ID not found. Initialize the adapter first")
             msg = "Zone ID not found"
             raise ValueError(msg)
         try:
