@@ -1,10 +1,11 @@
 """Liquid AI LFM embeddings adapter implementation for memory-efficient edge deployment."""
 
 import time
+
 import typing as t
 from datetime import datetime
-
 from pydantic import Field
+
 from acb.adapters import (
     AdapterCapability,
     AdapterMetadata,
@@ -417,7 +418,7 @@ class LiquidLFMEmbedding(EmbeddingAdapter):
     async def _optimize_memory(self) -> None:
         """Optimize memory usage when approaching limits."""
         logger: t.Any = await depends.get("logger")
-        await logger.info("Memory limit approached, optimizing...")
+        await logger.info("Memory limit approached, optimizing")
 
         # LFM-specific memory optimization strategies would go here
         if self._memory_monitor:
