@@ -1,9 +1,10 @@
-import typing as t
 import warnings
-from contextlib import asynccontextmanager, suppress
 from functools import cached_property
 from uuid import UUID
 
+import typing as t
+from contextlib import asynccontextmanager, suppress
+
 try:
     import redis.asyncio as redis
 except Exception:  # pragma: no cover - allow tests without redis installed
@@ -155,7 +156,7 @@ class Nosql(NosqlBase):
     def client(self) -> t.Any:
         if not self._client:
             ssl_kwargs = self._build_ssl_kwargs()
-            self._client = redis.from_url(
+            self._client = redis.from_url(  # type: ignore[no-untyped-call]
                 self.config.nosql.connection_string,
                 decode_responses=self.config.nosql.decode_responses,
                 encoding=self.config.nosql.encoding,
