@@ -1,17 +1,17 @@
 """Tests for the base cache components."""
 
-import typing as t
 from unittest.mock import AsyncMock, MagicMock, patch
 
 import pytest
-from aiocache.backends.memory import SimpleMemoryCache
-from aiocache.serializers import PickleSerializer
-from acb.adapters.cache._base import CacheBaseSettings, MsgPackSerializer, CacheBase
+import typing as t
+
+from acb.adapters.cache._base import CacheBase, CacheBaseSettings, MsgPackSerializer
 from acb.adapters.cache.memory import Cache as MemoryCache
 from acb.config import Config
 
 
 class TestMsgPackSerializer:
+    @pytest.mark.unit
     def test_init(self) -> None:
         serializer: MsgPackSerializer = MsgPackSerializer()
         assert serializer.use_list
@@ -19,6 +19,7 @@ class TestMsgPackSerializer:
         serializer = MsgPackSerializer(use_list=False)
         assert not serializer.use_list
 
+    @pytest.mark.unit
     def test_dumps(self) -> None:
         serializer: MsgPackSerializer = MsgPackSerializer()
         test_data: dict[str, t.Any] = {
@@ -37,6 +38,7 @@ class TestMsgPackSerializer:
             mock_compress.assert_called_once_with(b"encoded_data")
             assert result == "compressed_data"
 
+    @pytest.mark.unit
     def test_loads(self) -> None:
         serializer: MsgPackSerializer = MsgPackSerializer()
         test_data: str = "compressed_data"
@@ -50,16 +52,19 @@ class TestMsgPackSerializer:
             mock_decompress.assert_called_once_with(test_data.encode("latin-1"))
             assert result == {"key": "value"}
 
+    @pytest.mark.unit
     def test_loads_empty_string(self) -> None:
         serializer: MsgPackSerializer = MsgPackSerializer()
         result: t.Any = serializer.loads("")
         assert result is None
 
+    @pytest.mark.unit
     def test_loads_none_value(self) -> None:
         serializer: MsgPackSerializer = MsgPackSerializer()
         result: t.Any = serializer.loads(None)  # type: ignore
         assert result is None
 
+    @pytest.mark.unit
     def test_loads_no_decompressed_data(self) -> None:
         """Test handling when decompress.brotli returns empty data."""
         serializer: MsgPackSerializer = MsgPackSerializer()
@@ -71,6 +76,7 @@ class TestMsgPackSerializer:
             result: t.Any = serializer.loads(test_data)
             assert result is None
 
+    @pytest.mark.unit
     def test_integration(self) -> None:
         serializer: MsgPackSerializer = MsgPackSerializer()
         test_data: dict[str, t.Any] = {
@@ -93,6 +99,7 @@ class TestCacheBaseSettings:
         config.deployed = False
         return config
 
+    @pytest.mark.unit
     def test_init_default_values(self, mock_config: MagicMock) -> None:
         with patch("acb.adapters.cache._base.depends.get", return_value=mock_config):
             settings = CacheBaseSettings()
@@ -101,6 +108,7 @@ class TestCacheBaseSettings:
             assert settings.host.get_secret_value() == "127.0.0.1"
             assert settings.response_ttl == 1  # Not deployed, so 1
 
+    @pytest.mark.unit
     def test_init_custom_values(self, mock_config: MagicMock) -> None:
         with patch("acb.adapters.cache._base.depends.get", return_value=mock_config):
             settings = CacheBaseSettings(
@@ -112,6 +120,7 @@ class TestCacheBaseSettings:
             assert settings.host.get_secret_value() == "custom.host"
             assert settings.port == 1234
 
+    @pytest.mark.unit
     def test_init_deployed(self) -> None:
         # Create a mock config with deployed=True
         mock_config = MagicMock(spec=Config)
@@ -141,6 +150,7 @@ class TestCacheBase:
         """Create a mock cache instance."""
         return self.MockCache()
 
+    @pytest.mark.unit
     def test_init(self) -> None:
         """Test CacheBase initialization."""
         cache = self.MockCache()
@@ -159,6 +169,7 @@ class TestCacheBase:
     @pytest.mark.asyncio
     async def test_create_client_not_implemented(self) -> None:
         """Test that _create_client raises NotImplementedError."""
+
         class IncompleteCache(CacheBase):
             pass
 
@@ -170,7 +181,7 @@ class TestCacheBase:
     async def test_cleanup_resources(self, mock_cache: MockCache) -> None:
         """Test _cleanup_resources method."""
         # First ensure we have a client
-        client = await mock_cache._ensure_client()
+        await mock_cache._ensure_client()
         assert mock_cache._client is not None
 
         # Test cleanup
@@ -194,6 +205,7 @@ class TestCacheBase:
 
 
 class TestMemoryCache:
+    @pytest.mark.unit
     def test_init(self) -> None:
         cache = MemoryCache()
         assert cache is not None
