@@ -6,6 +6,7 @@ import pytest
 from aiocache.backends.memory import SimpleMemoryCache
 from aiocache.serializers import PickleSerializer
 from pytest_benchmark.fixture import BenchmarkFixture
+
 from acb.adapters.cache._base import CacheBaseSettings
 from acb.adapters.cache.memory import Cache, CacheSettings
 
@@ -24,39 +25,57 @@ def mock_logger() -> MagicMock:
 
 
 class TestCacheSettings:
+    @pytest.mark.unit
     def test_default_values(self) -> None:
         settings = CacheSettings()
         assert settings.default_ttl == 86400
         assert settings.query_ttl == 600
         assert settings.template_ttl == 86400
 
+    @pytest.mark.unit
     def test_custom_values(self) -> None:
         settings = CacheSettings(default_ttl=3600, query_ttl=300, template_ttl=7200)
         assert settings.default_ttl == 3600
         assert settings.query_ttl == 300
         assert settings.template_ttl == 7200
 
-    def test_response_ttl_with_config(self, mock_config: MagicMock) -> None:
+    @pytest.mark.unit
+    def test_response_ttl_deployed_false(self) -> None:
         from acb.config import Config
         from acb.depends import depends
 
         # Test with deployed=False
+        mock_config = MagicMock()
         mock_config.deployed = False
         depends.set(Config, mock_config)
         try:
             settings = CacheBaseSettings()
             assert settings.response_ttl == 1
         finally:
-            depends.set(Config, Config())
+            # Reset to avoid affecting other tests
+            try:
+                depends.set(Config, Config())
+            except Exception:
+                pass
+
+    @pytest.mark.unit
+    def test_response_ttl_deployed_true(self) -> None:
+        from acb.config import Config
+        from acb.depends import depends
 
         # Test with deployed=True
+        mock_config = MagicMock()
         mock_config.deployed = True
         depends.set(Config, mock_config)
         try:
             settings = CacheBaseSettings()
             assert settings.response_ttl == settings.default_ttl
         finally:
-            depends.set(Config, Config())
+            # Reset to avoid affecting other tests
+            try:
+                depends.set(Config, Config())
+            except Exception:
+                pass
 
 
 class TestMemoryCache:
@@ -370,7 +389,9 @@ class TestMemoryCache:
 
         # Create a mock multi-tier cache that raises an exception
         mock_multi_tier_cache = MagicMock()
-        mock_multi_tier_cache.cleanup = AsyncMock(side_effect=Exception("Multi-tier cleanup failed"))
+        mock_multi_tier_cache.cleanup = AsyncMock(
+            side_effect=Exception("Multi-tier cleanup failed")
+        )
         adapter._multi_tier_cache = mock_multi_tier_cache
 
         # Create a mock client
