@@ -1,39 +1,42 @@
 """Tests for the ACB Pydantic model adapter."""
-from typing import Optional, List, Dict, Any, Union
-from unittest.mock import Mock, MagicMock, patch
+
+from unittest.mock import Mock, patch
 
 import pytest
 from pydantic import BaseModel, Field
+from typing import Any
 
 from acb.adapters.models._pydantic import (
-    PydanticModelAdapter,
     PYDANTIC_AVAILABLE,
+    PydanticModelAdapter,
+)
+from acb.adapters.models._pydantic import (
     BaseModel as LocalBaseModel,
 )
 
 
-# Define test models
-class TestUser(BaseModel):
+# Define test models (using "Sample" prefix to avoid pytest collection warnings)
+class SampleUser(BaseModel):
     id: int
     name: str
     email: str
-    age: Optional[int] = None
+    age: int | None = None
     is_active: bool = True
 
 
-class TestProfile(BaseModel):
+class SampleProfile(BaseModel):
     bio: str
-    website: Optional[str] = None
+    website: str | None = None
 
 
-class TestUserWithProfile(BaseModel):
+class SampleUserWithProfile(BaseModel):
     id: int
     name: str
-    profile: TestProfile
-    profiles: List[TestProfile]
+    profile: SampleProfile
+    profiles: list[SampleProfile]
 
 
-class TestUserWithConfig(BaseModel):
+class SampleUserWithConfig(BaseModel):
     id: int
     name: str
 
@@ -42,17 +45,14 @@ class TestUserWithConfig(BaseModel):
         primary_key = "id"
 
 
-class TestUserWithModelConfig(BaseModel):
+class SampleUserWithModelConfig(BaseModel):
     id: int
     name: str
 
-    model_config = {
-        "collection_name": "modern_users",
-        "primary_key": "user_id"
-    }
+    model_config = {"collection_name": "modern_users", "primary_key": "user_id"}
 
 
-class TestUserWithMethods(BaseModel):
+class SampleUserWithMethods(BaseModel):
     id: int
     name: str
 
@@ -66,16 +66,16 @@ class TestUserWithMethods(BaseModel):
 
 
 # Define models with aliases
-class TestUserWithAlias(BaseModel):
+class SampleUserWithAlias(BaseModel):
     user_id: int = Field(alias="id")
     full_name: str = Field(alias="name")
 
 
-# Test for nested models
-class TestCompany(BaseModel):
+# Sample for nested models
+class SampleCompany(BaseModel):
     id: int
     name: str
-    employees: List[TestUser]
+    employees: list[SampleUser]
 
 
 class TestPydanticModelAdapter:
@@ -96,9 +96,11 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        instance = adapter.create_instance(TestUser, id=1, name="John", email="john@example.com")
+        instance = adapter.create_instance(
+            SampleUser, id=1, name="John", email="john@example.com"
+        )
 
-        assert isinstance(instance, TestUser)
+        assert isinstance(instance, SampleUser)
         assert instance.id == 1
         assert instance.name == "John"
         assert instance.email == "john@example.com"
@@ -110,7 +112,7 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        user = TestUser(id=1, name="John", email="john@example.com", age=30)
+        user = SampleUser(id=1, name="John", email="john@example.com", age=30)
 
         assert adapter.get_field_value(user, "id") == 1
         assert adapter.get_field_value(user, "name") == "John"
@@ -123,7 +125,7 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        user = TestUser(id=1, name="John", email="john@example.com", age=30)
+        user = SampleUser(id=1, name="John", email="john@example.com", age=30)
 
         # Serialize should use model_dump method for Pydantic v2
         serialized = adapter.serialize(user)
@@ -132,7 +134,7 @@ class TestPydanticModelAdapter:
             "name": "John",
             "email": "john@example.com",
             "age": 30,
-            "is_active": True
+            "is_active": True,
         }
 
     def test_serialize_legacy_pydantic(self) -> None:
@@ -141,7 +143,7 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        user = TestUser(id=1, name="John", email="john@example.com", age=30)
+        user = SampleUser(id=1, name="John", email="john@example.com", age=30)
 
         # Pydantic v2 has model_dump, test serialization with the real method
         serialized = adapter.serialize(user)
@@ -150,7 +152,7 @@ class TestPydanticModelAdapter:
             "name": "John",
             "email": "john@example.com",
             "age": 30,
-            "is_active": True
+            "is_active": True,
         }
 
     def test_manual_serialize_with_model_fields(self) -> None:
@@ -159,7 +161,7 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        user = TestUser(id=1, name="John", email="john@example.com", age=30)
+        user = SampleUser(id=1, name="John", email="john@example.com", age=30)
 
         # Test serialization - should use model_dump for Pydantic v2
         serialized = adapter.serialize(user)
@@ -168,7 +170,7 @@ class TestPydanticModelAdapter:
             "name": "John",
             "email": "john@example.com",
             "age": 30,
-            "is_active": True
+            "is_active": True,
         }
 
     def test_manual_serialize_with_nested_models(self) -> None:
@@ -177,12 +179,9 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        profile = TestProfile(bio="Software developer", website="https://example.com")
+        profile = SampleProfile(bio="Software developer", website="https://example.com")
         user = TestUserWithProfile(
-            id=1,
-            name="John",
-            profile=profile,
-            profiles=[profile]
+            id=1, name="John", profile=profile, profiles=[profile]
         )
 
         # Test serialization - should handle nested models
@@ -201,13 +200,11 @@ class TestPydanticModelAdapter:
 
         class TestDataModel(BaseModel):
             id: int
-            tags: List[str]
-            metadata: Dict[str, Any]
+            tags: list[str]
+            metadata: dict[str, Any]
 
         data = TestDataModel(
-            id=1,
-            tags=["tag1", "tag2"],
-            metadata={"key": "value", "count": 42}
+            id=1, tags=["tag1", "tag2"], metadata={"key": "value", "count": 42}
         )
 
         # Test serialization
@@ -223,7 +220,10 @@ class TestPydanticModelAdapter:
 
         adapter = PydanticModelAdapter()
 
-        with pytest.raises(NotImplementedError, match="Deserialize requires specific model class context"):
+        with pytest.raises(
+            NotImplementedError,
+            match="Deserialize requires specific model class context",
+        ):
             adapter.deserialize({"id": 1, "name": "John"})
 
     def test_deserialize_to_class_success(self) -> None:
@@ -234,8 +234,8 @@ class TestPydanticModelAdapter:
         adapter = PydanticModelAdapter()
         data = {"id": 1, "name": "John", "email": "john@example.com", "age": 30}
 
-        user = adapter.deserialize_to_class(TestUser, data)
-        assert isinstance(user, TestUser)
+        user = adapter.deserialize_to_class(SampleUser, data)
+        assert isinstance(user, SampleUser)
         assert user.id == 1
         assert user.name == "John"
         assert user.email == "john@example.com"
@@ -252,11 +252,11 @@ class TestPydanticModelAdapter:
             "name": "John",
             "email": "john@example.com",
             "extra_field": "should_be_filtered",
-            "another_extra": "also_filtered"
+            "another_extra": "also_filtered",
         }
 
-        user = adapter.deserialize_to_class(TestUser, data)
-        assert isinstance(user, TestUser)
+        user = adapter.deserialize_to_class(SampleUser, data)
+        assert isinstance(user, SampleUser)
         assert user.id == 1
         assert user.name == "John"
         assert user.email == "john@example.com"
@@ -272,11 +272,11 @@ class TestPydanticModelAdapter:
             "id": 1,
             "name": "John",
             "email": "john@example.com",
-            "extra_field": "filtered"
+            "extra_field": "filtered",
         }
 
         # Pydantic v2 models have model_fields, test filtering works properly
-        filtered_data = adapter._filter_data_for_model(TestUser, data)
+        filtered_data = adapter._filter_data_for_model(SampleUser, data)
         assert filtered_data == {"id": 1, "name": "John", "email": "john@example.com"}
 
     def test_filter_data_for_model_with_model_fields(self) -> None:
@@ -289,7 +289,7 @@ class TestPydanticModelAdapter:
             "id": 1,
             "name": "John",
             "email": "john@example.com",
-            "extra_field": "filtered"
+            "extra_field": "filtered",
         }
 
         # Mock model_fields attribute
@@ -300,13 +300,21 @@ class TestPydanticModelAdapter:
         mock_field_info3 = Mock()
         mock_field_info3.name = "email"
 
-        with patch.object(TestUser, "model_fields", {
-            "id": mock_field_info1,
-            "name": mock_field_info2,
-            "email": mock_field_info3
-        }):
-            filtered_data = adapter._filter_data_for_model(TestUser, data)
-            assert filtered_data == {"id": 1, "name": "John", "email": "john@example.com"}
+        with patch.object(
+            SampleUser,
+            "model_fields",
+            {
+                "id": mock_field_info1,
+                "name": mock_field_info2,
+                "email": mock_field_info3,
+            },
+        ):
+            filtered_data = adapter._filter_data_for_model(SampleUser, data)
+            assert filtered_data == {
+                "id": 1,
+                "name": "John",
+                "email": "john@example.com",
+            }
 
     def test_get_entity_name_with_tablename(self) -> None:
         """Test getting entity name with tablename in Config."""
@@ -374,7 +382,7 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        name = adapter.get_entity_name(TestUser)
+        name = adapter.get_entity_name(SampleUser)
         assert name == "testuser"
 
     def test_get_field_mapping_with_model_fields(self) -> None:
@@ -383,7 +391,7 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        mapping = adapter.get_field_mapping(TestUser)
+        mapping = adapter.get_field_mapping(SampleUser)
 
         # Should have all the standard fields
         assert "id" in mapping
@@ -433,7 +441,7 @@ class TestPydanticModelAdapter:
         adapter = PydanticModelAdapter()
         data = {"id": 1, "name": "John", "email": "john@example.com"}
 
-        validated_data = adapter.validate_data(TestUser, data)
+        validated_data = adapter.validate_data(SampleUser, data)
         assert "id" in validated_data
         assert "name" in validated_data
         assert "email" in validated_data
@@ -448,10 +456,10 @@ class TestPydanticModelAdapter:
             "id": 1,
             "name": "John",
             "email": "john@example.com",
-            "extra_field": "filtered"
+            "extra_field": "filtered",
         }
 
-        validated_data = adapter.validate_data(TestUser, data)
+        validated_data = adapter.validate_data(SampleUser, data)
         assert "id" in validated_data
         assert "name" in validated_data
         assert "email" in validated_data
@@ -490,7 +498,7 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        pk_field = adapter.get_primary_key_field(TestUser)
+        pk_field = adapter.get_primary_key_field(SampleUser)
         assert pk_field == "id"
 
     def test_get_primary_key_field_default(self) -> None:
@@ -515,9 +523,9 @@ class TestPydanticModelAdapter:
         adapter = PydanticModelAdapter()
 
         # Test different field types
-        id_type = adapter.get_field_type(TestUser, "id")
-        name_type = adapter.get_field_type(TestUser, "name")
-        age_type = adapter.get_field_type(TestUser, "age")
+        id_type = adapter.get_field_type(SampleUser, "id")
+        name_type = adapter.get_field_type(SampleUser, "name")
+        age_type = adapter.get_field_type(SampleUser, "age")
 
         assert id_type is int
         assert name_type is str
@@ -529,7 +537,7 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        age_type = adapter.get_field_type(TestUser, "age")
+        age_type = adapter.get_field_type(SampleUser, "age")
         assert age_type is int  # Should unwrap Optional[int] to int
 
     def test_get_field_type_with_union(self) -> None:
@@ -540,7 +548,7 @@ class TestPydanticModelAdapter:
         adapter = PydanticModelAdapter()
 
         class TestModelWithUnion(BaseModel):
-            value: Union[int, str]
+            value: int | str
 
         value_type = adapter.get_field_type(TestModelWithUnion, "value")
         # Union types might be unwrapped differently depending on implementation
@@ -584,7 +592,7 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        is_relationship = adapter.is_relationship_field(TestUser, "name")
+        is_relationship = adapter.is_relationship_field(SampleUser, "name")
         assert is_relationship is False
 
     def test_get_nested_model_class_list(self) -> None:
@@ -594,7 +602,7 @@ class TestPydanticModelAdapter:
 
         adapter = PydanticModelAdapter()
         nested_class = adapter.get_nested_model_class(TestUserWithProfile, "profiles")
-        assert nested_class is TestProfile
+        assert nested_class is SampleProfile
 
     def test_get_nested_model_class_single(self) -> None:
         """Test getting nested model class for single model fields."""
@@ -603,7 +611,7 @@ class TestPydanticModelAdapter:
 
         adapter = PydanticModelAdapter()
         nested_class = adapter.get_nested_model_class(TestUserWithProfile, "profile")
-        assert nested_class is TestProfile
+        assert nested_class is SampleProfile
 
     def test_get_nested_model_class_non_model(self) -> None:
         """Test getting nested model class for non-model fields."""
@@ -611,7 +619,7 @@ class TestPydanticModelAdapter:
             pytest.skip("Pydantic not available")
 
         adapter = PydanticModelAdapter()
-        nested_class = adapter.get_nested_model_class(TestUser, "name")
+        nested_class = adapter.get_nested_model_class(SampleUser, "name")
         assert nested_class is None
 
 
@@ -627,7 +635,7 @@ def test_base_model_alias() -> None:
     if PYDANTIC_AVAILABLE:
         # Should be the real Pydantic BaseModel
         assert LocalBaseModel is BaseModel
-        assert issubclass(TestUser, LocalBaseModel)
+        assert issubclass(SampleUser, LocalBaseModel)
     else:
         # Should be a fallback class
         assert LocalBaseModel is not None
