@@ -1,12 +1,13 @@
 """Tests for the file-based storage adapter."""
 
-import typing as t
 from unittest.mock import AsyncMock, MagicMock, PropertyMock, patch
 
 import pytest
+import typing as t
 from anyio import Path as AsyncPath
 from fsspec.implementations.dirfs import DirFileSystem
 from pytest_benchmark.fixture import BenchmarkFixture
+
 from acb.adapters.storage.file import (
     Storage,
     StorageSettings,
@@ -182,7 +183,9 @@ class TestFileStorage:
         assert Storage.file_system == DirFileSystem
 
     @pytest.mark.asyncio
-    async def test_init_method(self, storage_adapter: Storage, mock_config: MagicMock) -> None:
+    async def test_init_method(
+        self, storage_adapter: Storage, mock_config: MagicMock
+    ) -> None:
         mock_client = MockAsyncFileSystemWrapper()
 
         storage_adapter._client = mock_client
@@ -193,9 +196,13 @@ class TestFileStorage:
             await storage_adapter.init()
 
             # StorageBucket is called with (client, bucket_name, config)
-            mock_bucket_cls.assert_any_call(mock_client, "templates", storage_adapter.config)
+            mock_bucket_cls.assert_any_call(
+                mock_client, "templates", storage_adapter.config
+            )
             mock_bucket_cls.assert_any_call(mock_client, "test", storage_adapter.config)
-            mock_bucket_cls.assert_any_call(mock_client, "media", storage_adapter.config)
+            mock_bucket_cls.assert_any_call(
+                mock_client, "media", storage_adapter.config
+            )
 
             assert storage_adapter.templates == mock_bucket
             assert storage_adapter.test == mock_bucket
