@@ -1,16 +1,16 @@
 """Comprehensive tests for the Storage Base adapter."""
 
-import typing as t
 from unittest.mock import AsyncMock, MagicMock
 
 import pytest
 from anyio import Path as AsyncPath
+
 from acb.adapters.storage._base import (
+    StorageBase,
     StorageBaseSettings,
     StorageBucket,
     StorageFile,
     StorageImage,
-    StorageBase,
 )
 from acb.config import Config
 
@@ -78,13 +78,19 @@ class TestStorageBucket:
     def mock_client(self) -> AsyncMock:
         """Create a mock client."""
         client = AsyncMock()
-        client.url = AsyncMock(return_value="https://example.com/test-bucket/test-prefix/test.txt")
-        client._sign = AsyncMock(return_value="https://signed.example.com/test-bucket/test-prefix/test.txt?signature=abc123")
-        client._info = AsyncMock(return_value={
-            "size": 1024,
-            "timeCreated": "2023-01-01T00:00:00Z",
-            "updated": "2023-01-02T00:00:00Z",
-        })
+        client.url = AsyncMock(
+            return_value="https://example.com/test-bucket/test-prefix/test.txt"
+        )
+        client._sign = AsyncMock(
+            return_value="https://signed.example.com/test-bucket/test-prefix/test.txt?signature=abc123"
+        )
+        client._info = AsyncMock(
+            return_value={
+                "size": 1024,
+                "timeCreated": "2023-01-01T00:00:00Z",
+                "updated": "2023-01-02T00:00:00Z",
+            }
+        )
         client._ls = AsyncMock(return_value=["file1.txt", "file2.txt"])
         client._exists = AsyncMock(return_value=True)
         client._mkdir = AsyncMock()
@@ -104,7 +110,9 @@ class TestStorageBucket:
         return config
 
     @pytest.fixture
-    def storage_bucket(self, mock_client: AsyncMock, mock_config: MagicMock) -> StorageBucket:
+    def storage_bucket(
+        self, mock_client: AsyncMock, mock_config: MagicMock
+    ) -> StorageBucket:
         """Create a StorageBucket instance."""
         return StorageBucket(mock_client, "test", mock_config, "test-prefix")
 
@@ -127,7 +135,9 @@ class TestStorageBucket:
         path_str = storage_bucket.get_path(path)
         assert path_str == "test-bucket/test-prefix/test/file.txt"
 
-    def test_get_path_local_fs(self, mock_client: AsyncMock, mock_config: MagicMock) -> None:
+    def test_get_path_local_fs(
+        self, mock_client: AsyncMock, mock_config: MagicMock
+    ) -> None:
         """Test get_path method with local filesystem."""
         mock_config.storage.local_fs = True
         bucket = StorageBucket(mock_client, "test", mock_config, "test-prefix")
@@ -139,9 +149,11 @@ class TestStorageBucket:
     def test_get_url(self, storage_bucket: StorageBucket) -> None:
         """Test get_url method."""
         path = AsyncPath("test/file.txt")
-        url = storage_bucket.get_url(path)
+        storage_bucket.get_url(path)
         # This will call the client.url method
-        storage_bucket.client.url.assert_called_once_with("test-bucket/test-prefix/test/file.txt")
+        storage_bucket.client.url.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt"
+        )
 
     @pytest.mark.asyncio
     async def test_get_date_created(self, storage_bucket: StorageBucket) -> None:
@@ -149,7 +161,9 @@ class TestStorageBucket:
         path = AsyncPath("test/file.txt")
         date_created = await storage_bucket.get_date_created(path)
         assert date_created == "2023-01-01T00:00:00Z"
-        storage_bucket.client._info.assert_called_once_with("test-bucket/test-prefix/test/file.txt")
+        storage_bucket.client._info.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt"
+        )
 
     @pytest.mark.asyncio
     async def test_get_date_updated(self, storage_bucket: StorageBucket) -> None:
@@ -157,7 +171,9 @@ class TestStorageBucket:
         path = AsyncPath("test/file.txt")
         date_updated = await storage_bucket.get_date_updated(path)
         assert date_updated == "2023-01-02T00:00:00Z"
-        storage_bucket.client._info.assert_called_once_with("test-bucket/test-prefix/test/file.txt")
+        storage_bucket.client._info.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt"
+        )
 
     @pytest.mark.asyncio
     async def test_get_size(self, storage_bucket: StorageBucket) -> None:
@@ -165,7 +181,9 @@ class TestStorageBucket:
         path = AsyncPath("test/file.txt")
         size = await storage_bucket.get_size(path)
         assert size == 1024
-        storage_bucket.client._info.assert_called_once_with("test-bucket/test-prefix/test/file.txt")
+        storage_bucket.client._info.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt"
+        )
 
     @pytest.mark.asyncio
     async def test_get_checksum(self, storage_bucket: StorageBucket) -> None:
@@ -178,7 +196,7 @@ class TestStorageBucket:
             mp.setattr("acb.actions.hash.hash", mock_hash)
 
             checksum = await storage_bucket.get_checksum(path)
-            assert checksum == 0x1234abcd
+            assert checksum == 0x1234ABCD
             mock_hash.crc32c.assert_called_once_with(path)
 
     @pytest.mark.asyncio
@@ -187,7 +205,9 @@ class TestStorageBucket:
         path = AsyncPath("test/file.txt")
         signed_url = await storage_bucket.get_signed_url(path, expires=1800)
         assert "signature" in signed_url
-        storage_bucket.client._sign.assert_called_once_with("test-bucket/test-prefix/test/file.txt", expires=1800)
+        storage_bucket.client._sign.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt", expires=1800
+        )
 
     @pytest.mark.asyncio
     async def test_stat(self, storage_bucket: StorageBucket) -> None:
@@ -197,7 +217,9 @@ class TestStorageBucket:
         assert "size" in stat_result
         assert "timeCreated" in stat_result
         assert "updated" in stat_result
-        storage_bucket.client._info.assert_called_once_with("test-bucket/test-prefix/test/file.txt")
+        storage_bucket.client._info.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt"
+        )
 
     @pytest.mark.asyncio
     async def test_stat_memory_fs(self, mock_config: MagicMock) -> None:
@@ -205,11 +227,13 @@ class TestStorageBucket:
         mock_config.storage.memory_fs = True
         # For memory_fs, use regular MagicMock (not AsyncMock) for synchronous methods
         mock_client = MagicMock()
-        mock_client.info = MagicMock(return_value={
-            "name": "test/file.txt",
-            "size": 1024,
-            "type": "file",
-        })
+        mock_client.info = MagicMock(
+            return_value={
+                "name": "test/file.txt",
+                "size": 1024,
+                "type": "file",
+            }
+        )
 
         # Create mock datetime objects
         mock_modified = MagicMock()
@@ -235,7 +259,9 @@ class TestStorageBucket:
         path = AsyncPath("test/")
         list_result = await storage_bucket.list(path)
         assert list_result == ["file1.txt", "file2.txt"]
-        storage_bucket.client._ls.assert_called_once_with("test-bucket/test-prefix/test")
+        storage_bucket.client._ls.assert_called_once_with(
+            "test-bucket/test-prefix/test"
+        )
 
     @pytest.mark.asyncio
     async def test_exists(self, storage_bucket: StorageBucket) -> None:
@@ -243,7 +269,9 @@ class TestStorageBucket:
         path = AsyncPath("test/file.txt")
         exists_result = await storage_bucket.exists(path)
         assert exists_result is True
-        storage_bucket.client._exists.assert_called_once_with("test-bucket/test-prefix/test/file.txt")
+        storage_bucket.client._exists.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt"
+        )
 
     @pytest.mark.asyncio
     async def test_exists_memory_fs(self, mock_config: MagicMock) -> None:
@@ -258,7 +286,9 @@ class TestStorageBucket:
         path = AsyncPath("test/file.txt")
         exists_result = await bucket.exists(path)
         assert exists_result is True
-        mock_client.isfile.assert_called_once_with("test-bucket/test-prefix/test/file.txt")
+        mock_client.isfile.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt"
+        )
 
     @pytest.mark.asyncio
     async def test_create_bucket(self, storage_bucket: StorageBucket) -> None:
@@ -268,7 +298,9 @@ class TestStorageBucket:
         storage_bucket.client._mkdir.assert_called_once()
 
     @pytest.mark.asyncio
-    async def test_create_bucket_media(self, mock_client: AsyncMock, mock_config: MagicMock) -> None:
+    async def test_create_bucket_media(
+        self, mock_client: AsyncMock, mock_config: MagicMock
+    ) -> None:
         """Test create_bucket method for media bucket."""
         # Add media bucket to config
         mock_config.storage.buckets = {"media": "media-bucket"}
@@ -280,7 +312,9 @@ class TestStorageBucket:
         bucket.client._mkdir.assert_called_once()
 
     @pytest.mark.asyncio
-    async def test_create_bucket_templates(self, mock_client: AsyncMock, mock_config: MagicMock) -> None:
+    async def test_create_bucket_templates(
+        self, mock_client: AsyncMock, mock_config: MagicMock
+    ) -> None:
         """Test create_bucket method for templates bucket."""
         # Add templates bucket to config
         mock_config.storage.buckets = {"templates": "templates-bucket"}
@@ -309,7 +343,9 @@ class TestStorageBucket:
 
         result = await storage_bucket.open(path)
         assert result == b"test content"
-        storage_bucket.client.open.assert_called_once_with("test-bucket/test-prefix/test/file.txt", "rb")
+        storage_bucket.client.open.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt", "rb"
+        )
 
     @pytest.mark.asyncio
     async def test_write(self, storage_bucket: StorageBucket) -> None:
@@ -317,10 +353,14 @@ class TestStorageBucket:
         path = AsyncPath("test/file.txt")
         test_data = b"test content"
         await storage_bucket.write(path, test_data)
-        storage_bucket.client._pipe_file.assert_called_once_with("test-bucket/test-prefix/test/file.txt", test_data)
+        storage_bucket.client._pipe_file.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt", test_data
+        )
 
     @pytest.mark.asyncio
-    async def test_write_memory_fs(self, mock_client: AsyncMock, mock_config: MagicMock) -> None:
+    async def test_write_memory_fs(
+        self, mock_client: AsyncMock, mock_config: MagicMock
+    ) -> None:
         """Test write method with memory filesystem."""
         mock_config.storage.memory_fs = True
 
@@ -329,14 +369,18 @@ class TestStorageBucket:
         path = AsyncPath("test/file.txt")
         test_data = b"test content"
         await bucket.write(path, test_data)
-        mock_client.pipe_file.assert_called_once_with("test-bucket/test-prefix/test/file.txt", test_data)
+        mock_client.pipe_file.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt", test_data
+        )
 
     @pytest.mark.asyncio
     async def test_delete(self, storage_bucket: StorageBucket) -> None:
         """Test delete method."""
         path = AsyncPath("test/file.txt")
         await storage_bucket.delete(path)
-        storage_bucket.client._rm_file.assert_called_once_with("test-bucket/test-prefix/test/file.txt")
+        storage_bucket.client._rm_file.assert_called_once_with(
+            "test-bucket/test-prefix/test/file.txt"
+        )
 
 
 class TestStorageFile:
@@ -382,16 +426,18 @@ class TestStorageFile:
     @pytest.mark.asyncio
     async def test_checksum_property(self, mock_storage_bucket: AsyncMock) -> None:
         """Test checksum property."""
-        mock_storage_bucket.get_checksum = AsyncMock(return_value=0x1234abcd)
+        mock_storage_bucket.get_checksum = AsyncMock(return_value=0x1234ABCD)
         file = StorageFile(name="test.txt", storage=mock_storage_bucket)
         checksum = await file.checksum
-        assert checksum == 0x1234abcd
+        assert checksum == 0x1234ABCD
         mock_storage_bucket.get_checksum.assert_called_once_with(AsyncPath("test.txt"))
 
     @pytest.mark.asyncio
     async def test_open_method(self, mock_storage_bucket: AsyncMock) -> None:
         """Test open method."""
-        mock_storage_bucket.open = AsyncMock(return_value=AsyncMock(read=AsyncMock(return_value=b"test content")))
+        mock_storage_bucket.open = AsyncMock(
+            return_value=AsyncMock(read=AsyncMock(return_value=b"test content"))
+        )
         file = StorageFile(name="test.txt", storage=mock_storage_bucket)
         result = await file.open()
         assert result is not None
@@ -404,7 +450,9 @@ class TestStorageFile:
         mock_storage_bucket.write = AsyncMock()
         file = StorageFile(name="test.txt", storage=mock_storage_bucket)
         await file.write(mock_file)
-        mock_storage_bucket.write.assert_called_once_with(path=AsyncPath("test.txt"), data=mock_file)
+        mock_storage_bucket.write.assert_called_once_with(
+            path=AsyncPath("test.txt"), data=mock_file
+        )
 
     def test_str_method(self, mock_storage_bucket: AsyncMock) -> None:
         """Test __str__ method."""
@@ -510,7 +558,10 @@ class TestStorageBase:
     @pytest.mark.asyncio
     async def test_init_buckets(self, storage_base: StorageBase) -> None:
         """Test init method for bucket initialization."""
-        storage_base.config.storage.buckets = {"test": "test-bucket", "media": "media-bucket"}
+        storage_base.config.storage.buckets = {
+            "test": "test-bucket",
+            "media": "media-bucket",
+        }
         await storage_base.init()
         assert hasattr(storage_base, "test")
         assert hasattr(storage_base, "media")
@@ -539,7 +590,9 @@ class TestStorageBase:
         # Set up a mock bucket
         mock_bucket = AsyncMock()
         mock_context = AsyncMock()
-        mock_context.__aenter__ = AsyncMock(return_value=AsyncMock(read=AsyncMock(return_value=b"test content")))
+        mock_context.__aenter__ = AsyncMock(
+            return_value=AsyncMock(read=AsyncMock(return_value=b"test content"))
+        )
         mock_context.__aexit__ = AsyncMock()
         mock_bucket.open.return_value = mock_context
         storage_base.test = mock_bucket
