@@ -6,12 +6,13 @@ from pathlib import Path
 from unittest.mock import MagicMock, patch
 
 import pytest
+
 from acb.config import (
     AppSettings,
     DebugSettings,
     Settings,
-    _detect_library_usage,
 )
+from acb.context import get_context
 
 
 @pytest.mark.unit
@@ -123,16 +124,18 @@ class TestConfig:
     def test_library_usage_detection_setup_py(self) -> None:
         # Reset context to ensure fresh state
         from acb.context import reset_context
+
         reset_context()
 
         with patch("sys.argv", ["setup.py"]):
             with patch("acb.config._testing", False):
                 with patch.dict(os.environ, {}, clear=True):
-                    assert _detect_library_usage()
+                    assert get_context().is_library_mode()
 
     def test_library_usage_detection_env_var(self) -> None:
         # Reset context to ensure fresh state
         from acb.context import reset_context
+
         reset_context()
 
         with patch.dict(os.environ, {"ACB_LIBRARY_MODE": "true"}):
@@ -140,7 +143,7 @@ class TestConfig:
                 # We need to temporarily remove pytest from sys.modules
                 pytest_module = sys.modules.pop("pytest", None)
                 try:
-                    assert _detect_library_usage()
+                    assert get_context().is_library_mode()
                 finally:
                     if pytest_module is not None:
                         sys.modules["pytest"] = pytest_module
@@ -149,7 +152,7 @@ class TestConfig:
         with patch.dict(os.environ, {}, clear=True):
             with patch("acb.config.Path") as mock_path:
                 mock_path.cwd.return_value.glob.return_value = []
-                result = _detect_library_usage()
+                result = get_context().is_library_mode()
                 # This should return False for normal usage
                 assert isinstance(result, bool)  # Allow both since environment can vary
 
